@@ -28,6 +28,8 @@ import (
 	"github.com/traefik/traefik/v3/pkg/server/middleware"
 	"github.com/traefik/traefik/v3/pkg/server/provider"
 	"github.com/traefik/traefik/v3/pkg/server/service/loadbalancer/failover"
+	"github.com/traefik/traefik/v3/pkg/server/service/loadbalancer/hrw"
+	"github.com/traefik/traefik/v3/pkg/server/service/loadbalancer/leasttime"
 	"github.com/traefik/traefik/v3/pkg/server/service/loadbalancer/mirror"
 	"github.com/traefik/traefik/v3/pkg/server/service/loadbalancer/p2c"
 	"github.com/traefik/traefik/v3/pkg/server/service/loadbalancer/wrr"
@@ -137,6 +139,13 @@ func (m *Manager) BuildHTTP(rootCtx context.Context, serviceName string) (http.H
 			conf.AddError(err, true)
 			return nil, err
 		}
+	case conf.HighestRandomWeight != nil:
+		var err error
+		lb, err = m.getHRWServiceHandler(ctx, serviceName, conf.HighestRandomWeight)
+		if err != nil {
+			conf.AddError(err, true)
+			return nil, err
+		}
 	case conf.Mirroring != nil:
 		var err error
 		lb, err = m.getMirrorServiceHandler(ctx, conf.Mirroring)
@@ -258,19 +267,18 @@ func (m *Manager) getWRRServiceHandler(ctx context.Context, serviceName string,
 			continue
 		}
 
-		childName := service.Name
 		updater, ok := serviceHandler.(healthcheck.StatusUpdater)
 		if !ok {
-			return nil, fmt.Errorf("child service %v of %v not a healthcheck.StatusUpdater (%T)", childName, serviceName, serviceHandler)
+			return nil, fmt.Errorf("child service %v of %v not a healthcheck.StatusUpdater (%T)", service.Name, serviceName, serviceHandler)
 		}
 
 		if err := updater.RegisterStatusUpdater(func(up bool) {
-			balancer.SetStatus(ctx, childName, up)
+			balancer.SetStatus(ctx, service.Name, up)
 		}); err != nil {
-			return nil, fmt.Errorf("cannot register %v as updater for %v: %w", childName, serviceName, err)
+			return nil, fmt.Errorf("cannot register %v as updater for %v: %w", service.Name, serviceName, err)
 		}
 
-		log.Ctx(ctx).Debug().Str("parent", serviceName).Str("child", childName).
+		log.Ctx(ctx).Debug().Str("parent", serviceName).Str("child", service.Name).
 			Msg("Child service will update parent on status change")
 	}
 
@@ -278,13 +286,13 @@ func (m *Manager) getWRRServiceHandler(ctx context.Context, serviceName string,
 }
 
 func (m *Manager) getServiceHandler(ctx context.Context, service dynamic.WRRService) (http.Handler, error) {
-	switch {
-	case service.Status != nil:
+	if service.Status != nil {
 		return http.HandlerFunc(func(rw http.ResponseWriter, req *http.Request) {
 			rw.WriteHeader(*service.Status)
 		}), nil
+	}
 
-	case service.GRPCStatus != nil:
+	if service.GRPCStatus != nil {
 		return http.HandlerFunc(func(rw http.ResponseWriter, req *http.Request) {
 			st := status.New(service.GRPCStatus.Code, service.GRPCStatus.Msg)
 
@@ -299,10 +307,57 @@ func (m *Manager) getServiceHandler(ctx context.Context, service dynamic.WRRServ
 
 			_, _ = rw.Write(body)
 		}), nil
-
-	default:
-		return m.BuildHTTP(ctx, service.Name)
 	}
+
+	svcHandler, err := m.BuildHTTP(ctx, service.Name)
+	if err != nil {
+		return nil, fmt.Errorf("building HTTP service: %w", err)
+	}
+
+	if service.Headers != nil {
+		return http.HandlerFunc(func(rw http.ResponseWriter, req *http.Request) {
+			for k, v := range service.Headers {
+				req.Header.Set(k, v)
+			}
+
+			svcHandler.ServeHTTP(rw, req)
+		}), nil
+	}
+
+	return svcHandler, nil
+}
+
+func (m *Manager) getHRWServiceHandler(ctx context.Context, serviceName string, config *dynamic.HighestRandomWeight) (http.Handler, error) {
+	// TODO Handle accesslog and metrics with multiple service name
+	balancer := hrw.New(config.HealthCheck != nil)
+	for _, service := range shuffle(config.Services, m.rand) {
+		serviceHandler, err := m.BuildHTTP(ctx, service.Name)
+		if err != nil {
+			return nil, err
+		}
+
+		balancer.Add(service.Name, serviceHandler, service.Weight, false)
+
+		if config.HealthCheck == nil {
+			continue
+		}
+
+		updater, ok := serviceHandler.(healthcheck.StatusUpdater)
+		if !ok {
+			return nil, fmt.Errorf("child service %v of %v not a healthcheck.StatusUpdater (%T)", service.Name, serviceName, serviceHandler)
+		}
+
+		if err := updater.RegisterStatusUpdater(func(up bool) {
+			balancer.SetStatus(ctx, service.Name, up)
+		}); err != nil {
+			return nil, fmt.Errorf("cannot register %v as updater for %v: %w", service.Name, serviceName, err)
+		}
+
+		log.Ctx(ctx).Debug().Str("parent", serviceName).Str("child", service.Name).
+			Msg("Child service will update parent on status change")
+	}
+
+	return balancer, nil
 }
 
 type serverBalancer interface {
@@ -341,15 +396,30 @@ func (m *Manager) getLoadBalancerServiceHandler(ctx context.Context, serviceName
 	var lb serverBalancer
 	switch service.Strategy {
 	// Here we are handling the empty value to comply with providers that are not applying defaults (e.g. REST provider)
-	// TODO: remove this when all providers apply default values.
+	// TODO: remove this empty check when all providers apply default values.
 	case dynamic.BalancerStrategyWRR, "":
 		lb = wrr.New(service.Sticky, service.HealthCheck != nil)
 	case dynamic.BalancerStrategyP2C:
 		lb = p2c.New(service.Sticky, service.HealthCheck != nil)
+	case dynamic.BalancerStrategyHRW:
+		lb = hrw.New(service.HealthCheck != nil)
+	case dynamic.BalancerStrategyLeastTime:
+		lb = leasttime.New(service.Sticky, service.HealthCheck != nil)
 	default:
 		return nil, fmt.Errorf("unsupported load-balancer strategy %q", service.Strategy)
 	}
 
+	var passiveHealthChecker *healthcheck.PassiveServiceHealthChecker
+	if service.PassiveHealthCheck != nil {
+		passiveHealthChecker = healthcheck.NewPassiveHealthChecker(
+			serviceName,
+			lb,
+			service.PassiveHealthCheck.MaxFailedAttempts,
+			service.PassiveHealthCheck.FailureWindow,
+			service.HealthCheck != nil,
+			m.observabilityMgr.MetricsRegistry())
+	}
+
 	healthCheckTargets := make(map[string]*url.URL)
 
 	for i, server := range shuffle(service.Servers, m.rand) {
@@ -368,6 +438,11 @@ func (m *Manager) getLoadBalancerServiceHandler(ctx context.Context, serviceName
 			return nil, fmt.Errorf("error building proxy for server URL %s: %w", server.URL, err)
 		}
 
+		if passiveHealthChecker != nil {
+			// If passive health check is enabled, we wrap the proxy with the passive health checker.
+			proxy = passiveHealthChecker.WrapHandler(ctx, proxy, target.String())
+		}
+
 		// The retry wrapping must be done just before the proxy handler,
 		// to make sure that the retry will not be triggered/disabled by
 		// middlewares in the chain.
@@ -392,7 +467,7 @@ func (m *Manager) getLoadBalancerServiceHandler(ctx context.Context, serviceName
 
 		lb.AddServer(server.URL, proxy, server)
 
-		// servers are considered UP by default.
+		// Servers are considered UP by default.
 		info.UpdateServerStatus(target.String(), runtime.StatusUp)
 
 		healthCheckTargets[server.URL] = target
